Provádění hodnocení rizik pomocí nástroje OiRA | OiRA

Témata

# Provádění hodnocení rizik pomocí nástroje OiRA

## Spuštění nové relace

Chcete-li zahájit nové hodnocení rizik, klikněte na odkaz „Zahájit novou relaci“.

## Zahájení hodnocení rizik

Jakmile hodnocení rizik zahájíte, můžete je kdykoli vyhledat v přehledu v oddíle „Moje hodnocení rizik“. Zde můžete také zahájit nové hodnocení rizik.

Přehled.

## Navigace při hodnocení rizik

Každé hodnocení rizik vás provede několika kroky. Tyto kroky jsou viditelné v hlavní nabídce na levé straně obrazovky:

- Příprava
- Zapojení
- Identifikace + vyhodnocení
- Akční plán
- Zpráva
- Stav

V závislosti na rozhodnutích partnerů/vývojářů nástroje OiRA se struktura každého nástroje může lišit. V některých nástrojích zahrnuje fáze identifikace a vyhodnocení rizik akční plán. V tomto případě je nabídka vlevo následující:

- Příprava
- Zapojení
- Hodnocení
- Zpráva
- Stav

## Příprava

„Přípravou“ se rozumí situace, kdy spouštíte relaci/nástroj. Právě zde uvedete název hodnocení rizik, který vám později pomůže rozlišit několik různých hodnocení rizik, která jste pomocí nástroje provedli.

Odkaz „Více o tomto nástroji…“ poskytuje další informace o zvoleném nástroji a o stranách podílejících se na jeho vývoji.

Po kliknutí na tlačítko „Start“ mohou být v závislosti na nástroji, který používáte, položeny další otázky. Tato přípravná obrazovka s „profilovými otázkami“ se zobrazí pouze v případě nástrojů, které tuto možnost nabízejí.

Zde můžete:

- Vybrat nebo přeskočit situace v závislosti na tom, zda se vztahují na vaši podnikatelskou činnost. Zvolte „ano“, je-li to vhodné.
- Uvést více obchodních jednotek, poboček nebo obchodů atd. Související rizika se zopakují pro každou položku.

Obrazovka „profilu“ v přípravné fázi.

Přípravná fáze je velmi důležitá, neboť přesně definuje druh podnikání a související rizika, jimiž se vaše společnost zabývá. Po kliknutí na tlačítko „Uložit a pokračovat“ se dostanete do další sekce „Zapojení“.

Poznámka: Mnoho nástrojů nemá žádné profilové otázky, neboť se tento prvek k zacílení nástroje nevyužívá. V tomto případě se tato obrazovka automaticky přeskočí.

## Zapojení

Tento krok připomíná význam zapojení pracovníků a představuje různé způsoby, jak zajistit jejich řádné zapojení. Zde si můžete stáhnout nebo vytisknout obsah hodnocení rizik pro sdílení se svými pracovníky/zaměstnanci. Tím se zajistí, že pracovníci budou moci přispět k posouzení situace na pracovišti.

## Hodnocení

V tomto kroku určíte nebezpečí a problémy, jež jsou pro vaši společnost relevantní.

Poznámka: V závislosti na tom, jak byl nástroj partnerem OiRA nakonfigurován, může být do této obrazovky začleněn krok „akční plán“ (viz níže). V tomto případě se celá fáze nazývá „hodnocením“ a prvky popsané v „akčním plánu“ se objeví v rámci identifikace a vyhodnocení každého rizika.

Identifikace a vyhodnocení.

Na levé straně obrazovky se pod nadpisem „Identifikace + vyhodnocení“ / „Hodnocení“ zobrazí každé z témat/modulů obsažených v nástroji. Téma, které v současné době prohlížíte, je zvýrazněno.

### Identifikace

U každého rizika musíte rozhodnout, zda se na vaši společnost vztahuje tvrzení popisující požadovaný stav. Můžete odpovědět takto:

- Ano: pokud na tvrzení odpovíte „ano“, není třeba přijmout žádná další opatření, neboť jste riziko vyhodnotili jako nepřítomné.
- Ne: pokud na tvrzení odpovíte „ne“, je třeba podniknout další kroky. Budete vyzváni, abyste rozhodli o konkrétních opatřeních.
- Nepoužije se: některá tvrzení ohledně rizika umožňují zvolit možnost „nepoužije se“, není-li riziko pro vaši společnost/provozovnu relevantní.

Pod každým tvrzením je obvykle uvedeno více informací o konkrétním riziku:

- Informace: stručný popis, někdy s doprovodnými obrázky, s podrobnějšími údaji o riziku.
- Zdroje: další informace o riziku, například odkazy na právní předpisy a politiky. Někdy zde naleznete také připojené dokumenty k dalšímu prostudování.
- Připomínky: zde můžete uvést své připomínky, které se objeví ve vaší zprávě na konci hodnocení.

Poté, co odpovíte na tvrzení ohledně rizika a dalšího postupu, bude nabídka vlevo aktualizována pomocí barevného symbolu, který udává, zda jste:

- odpověděli kladně (zelené zaškrtnutí)
- odpověděli záporně (červený křížek)
- otázku odložili (oranžový otazník)

U nezodpovězených otázek zůstává šedý symbol.

### Vyhodnocení

V tomto kroku vyhodnotíte prioritu rizika, které jste určili.

Vyhodnocení rizika.

Poznámka: U některých nástrojů OiRA není vyhodnocení uvedeno. To závisí na tom, jak národní partner/vývojář nástroje OiRA konkrétní nástroj OiRA vytvořil.

Pokud jste zjistili, že existuje riziko (znázorněno červeným křížkem), objeví se sekce pro jeho vyhodnocení. Podle metody vyhodnocení stanovené pro každé riziko budete požádáni, abyste:

- odhadli prioritu: vysoká, střední nebo nízká

Stanovení priority rizika.

NEBO

- odpověděli na několik otázek týkajících se četnosti, závažnosti a pravděpodobnosti rizika, aby mohla být priorita vypočtena na základě vašich odpovědí.

Stanovení proměnných pro riziko.

### Prioritní rizika stanovená odvětvím:

Některá rizika považuje národní partner/vývojář nástroje, který konkrétní nástroj OiRA vytvořil, za velmi důležitá. Tato „prioritní rizika“ není třeba odhadnout, neboť jejich priorita bude automaticky nastavena jako „vysoká“.

Prioritní rizika.

### Zvláštní rizika

Poté, co jste se zabývali všemi tématy týkajícími se rizik v části „Identifikace + vyhodnocení“ / „Hodnocení“, objeví se nepovinné téma „Jiná rizika“. Tlačítkem „Přidat zvláštní riziko“ můžete vytvořit vlastní záznamy.

Jestliže v nástroji chybí rizika, která se vyskytují na vašem pracovišti / ve vaší společnosti, musíte je zde doplnit. Tato rizika můžete zcela definovat/formulovat vy sami.

Zvláštní rizika.

„Zvláštní riziko“ funguje velmi podobným způsobem jako rizika, která nabízí nástroj OiRA, musíte však samozřejmě napsat svůj vlastní text. Tímto textem by mělo být přinejmenším stručné tvrzení, které popisuje problematickou situaci, s možností delšího popisu. Můžete také nahrát obrázek, který ilustruje určitou situaci.

Stejně jako u běžných rizik musíte uvést, zda je riziko přítomno, či nikoli. To vám umožní odškrtnout zvláštní rizika, jakmile jste je úspěšně vyřešili, uchováte je však v hodnocení rizik pro účely dokumentace.

Můžete přidat tolik zvláštních rizik, kolik potřebujete.

Přidat zvláštní riziko.

## Akční plán

V tomto kroku rozhodujete o opatřeních, jež chcete zavést k odstranění či zmírnění rizik, která jste předtím určili.

Poznámka: Jak bylo uvedeno výše, akční plán je uveden v nabídce vlevo jako samostatný krok, nebo se objevuje u každého zjištěného rizika. Ve druhém případě se tento krok v nabídce nazývá „Hodnocení“ a zahrnuje jak tvrzení ohledně rizika, tak i výběr odpovědí.

To, kterou verzi máte k dispozici, závisí na rozhodnutích přijatých národním partnerem/vývojářem nástroje OiRA.

### Integrovaný akční plán

Integrovaný akční plán.

Pokud na určitou otázku odpovíte „ne“, pak se na stránce zobrazí modul akčního plánu pod nadpisem „Opatření“.

Můžete vybírat ze seznamu opatření, která systém navrhuje, i stanovit vlastní opatření.

### Samostatný akční plán

Představuje-li akční plán samostatný krok, bude přístupný prostřednictvím navigace vlevo.

Chcete-li plán spustit, klikněte na tlačítko „Vytvořit akční plán“.

V rámci akčního plánu nyní nabídka vlevo ukazuje pouze rizika, která byla označena jako rizika, u nichž jsou zapotřebí další opatření, neboť ostatní rizika byla označena jako nepřítomná.

U každého rizika, u něhož byla v procesu vyhodnocování uvedena odpověď „ne“, a u prioritních rizik (bez ohledu na kladnou či zápornou odpověď) budete vyzváni, abyste stanovili opatření.

Riziko v akčním plánu.

Můžete vybírat ze seznamu opatření, která systém navrhuje, i stanovit vlastní opatření.

#### Přidat vlastní opatření

Přidání dalšího opatření.

Ke stanovení preventivního opatření použijte tlačítko „Přidat opatření“. Měli byste:

- Popsat obecný přístup, který bude uplatněn k odstranění nebo snížení rizika.
- Volitelně uvést potřebnou úroveň odborných znalostí a/nebo požadavků (zde můžete např. uvést, zda je k řešení tohoto rizika zapotřebí zvláštní odborná příprava nebo externí odborné poradenství)
- Uvést informace o tom, kdo odpovídá za provedení.
- Případně určit rozpočet.
- Volitelně stanovit data, kdy má být provádění opatření zahájeno a kdy plánujete jeho dokončení.

Můžete přidat tolik opatření, kolik potřebujete.

#### Přidat standardní opatření

V závislosti na tom, jak partner/vývojář nástroje OiRA tento nástroj vytvořil, jsou pro jednotlivá rizika k dispozici předem stanovená opatření. Chcete-li zvolit jedno nebo více předem stanovených opatření, klikněte na tlačítko „Vybrat standardní opatření“.

Otevře se vyskakovací nabídka, která zobrazuje všechna navrhovaná opatření. U opatření, která chcete použít, klikněte na tlačítko „Přidat“.

Předem stanovená opatření jsou pak uvedena ve vašem akčním plánu. Popis toho, co je třeba udělat, je pevně stanoven, ostatní pole (odpovědnost, rozpočet, data) však můžete a měli byste vyplnit vy sami.

Přidat standardní opatření.

Standardní opatření i opatření, která jste definovali sami, lze kdykoli znovu vymazat.

## Zpráva

Po dokončení akčního plánu můžete vypracovat zprávu.

Chcete-li zanechat připomínku, která má být zahrnuta do zprávy, napište zde příslušný text a uložte jej.

Komentář ke zprávě.

Další informace o různých zprávách a o tom, jak je používat, viz zde.

## Stav

Malý kruhový diagram v nabídce vlevo zobrazuje pokrok, kterého jste pomocí nástroje dosáhli.

V sekci týkající se stavu je uveden přehled o tom, kolik rizik jste identifikovali, kolik z nich jste vyřešili rozhodnutím o opatřeních a kolika riziky/tvrzeními se ještě musíte zabývat.

Stavová stránka.

Když se dostanete na stavovou obrazovku, dozvíte se, jak daleko jste v každém modulu pokročili. To vám pomůže zjistit, kde ještě musíte posoudit rizika nebo stanovit opatření pro zjištěná rizika.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More